@@ -1,3 +1,4 @@
+"""Cmeel build."""
 from pathlib import Path
 from subprocess import check_call, check_output
 import logging
@@ -23,10 +24,13 @@ cmeel_run()
 
 
 class NonRelocatableError(Exception):
+    """Exception raised when absolute paths are in the final package."""
+
     pass
 
 
 def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
+    """Main entry point for PEP 517."""
     logging.info("CMake Wheel")
 
     TEMP = cmeel_config.temp_dir
@@ -54,6 +58,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         TEST_CMD = pyproject["build-system"].get(
             "test-cmd", ["cmake", "--build", "BUILD_DIR", "-t", "test"]
         )
+        CHECK_RELOCATABLE = pyproject["build-system"].get("check-relocatable", True)
     DISTRIBUTION = CONF["name"].replace("-", "_")
 
     logging.info("build wheel")
@@ -68,7 +73,8 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     if RUN_TESTS_AFTER_INSTALL:
         path = f"{INSTALL / SITELIB}"
-        if old := os.environ.get("PYTHONPATH", ""):
+        old = os.environ.get("PYTHONPATH", "")
+        if old:
             path += f"{os.pathsep}{old}"
         os.environ.update(PYTHONPATH=path)
 
@@ -98,6 +104,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         run_tests()
 
     logging.info("fix relocatablization")
+    # Replace absolute install path in generated .cmake files, if any.
     for f in INSTALL.rglob("*.cmake"):
         ff = INSTALL / f"{f.stem}.fix"
         with f.open("r") as fr, ff.open("w") as fw:
@@ -115,6 +122,15 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         readme = f.read()
     dependencies = ["cmeel"] + CONF.get("dependencies", [])
     requires = "\n".join([f"Requires-Dist: {dep}" for dep in dependencies])
+    urls = "\n".join(
+        [
+            f"Home-page: {val}"
+            if key == "homepage"
+            else f"Project-URL: {key.replace('-', ' ').capitalize()}, {val}"
+            for key, val in CONF["urls"].items()
+        ]
+    )
+
     with (dist_info / "METADATA").open("w") as f:
         if CONF["readme"].lower().endswith(".md"):
             content_type = "text/markdown"
@@ -129,12 +145,11 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
                     f"Name: {CONF['name']}",
                     f"Version: {CONF['version']}",
                     f"Summary: {CONF['description']}",
-                    f"Home-page: {CONF['urls']['homepage']}",
+                    f"License-Expression: {CONF['license']}",
                     "Classifier: Programming Language :: Python :: 3",
-                    "Classifier: License :: OSI Approved :: BSD License",
-                    "Classifier: Operating System :: POSIX :: Linux",
                     f"Requires-Python: {CONF.get('requires-python', '>=3.8')}",
                     f"Description-Content-Type: {content_type}",
+                    f"{urls}",
                     f"{requires}",
                     "",
                     f"{readme}",
@@ -170,33 +185,36 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
                 fe.write(EXECUTABLE)
             executable.chmod(0o755)
 
-    logging.info("check generated cmake files")
-    WRONG_DIRS = [
-        "/tmp/pip-build-env",
-        "/tmp/pip-req-build",
-        "/opt/_internal",
-        str(TEMP),
-    ]
-    for fc in INSTALL.glob("**/*.cmake"):
-        with fc.open() as f:
-            cmake_file = f.read()
-            if any(wrong_dir in cmake_file for wrong_dir in WRONG_DIRS):
-                lines = cmake_file.split("\n")
-                # Get indexes of of problematic lines
-                indexes = [
-                    idx
-                    for idx, line in enumerate(lines)
-                    if any(wrong_dir in line for wrong_dir in WRONG_DIRS)
-                ]
-                # Get lines at those indexes and around them to display
-                display = [
-                    f"{i}: {l}"
-                    for i, l in enumerate(lines)
-                    if any(idx in indexes for idx in (i - 2, i - 1, i, i + 1, i + 2))
-                ]
-                raise NonRelocatableError(
-                    f"{fc} references temporary paths:\n" + "\n".join(display)
-                )
+    if CHECK_RELOCATABLE:
+        logging.info("check generated cmake files")
+        WRONG_DIRS = [
+            "/tmp/pip-build-env",
+            "/tmp/pip-req-build",
+            "/opt/_internal",
+            str(TEMP),
+        ]
+        for fc in INSTALL.glob("**/*.cmake"):
+            with fc.open() as f:
+                cmake_file = f.read()
+                if any(wrong_dir in cmake_file for wrong_dir in WRONG_DIRS):
+                    lines = cmake_file.split("\n")
+                    # Get indexes of of problematic lines
+                    indexes = [
+                        idx
+                        for idx, line in enumerate(lines)
+                        if any(wrong_dir in line for wrong_dir in WRONG_DIRS)
+                    ]
+                    # Get lines at those indexes and around them to display
+                    display = [
+                        f"{i}: {l}"
+                        for i, l in enumerate(lines)
+                        if any(
+                            idx in indexes for idx in (i - 2, i - 1, i, i + 1, i + 2)
+                        )
+                    ]
+                    raise NonRelocatableError(
+                        f"{fc} references temporary paths:\n" + "\n".join(display)
+                    )
 
     logging.info("wheel pack")
     name = check_output(
